@@ -1,22 +1,10 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2004, 2005 Jakub Stachowski <qbast@go2.pl>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2004, 2005 Jakub Stachowski <qbast@go2.pl>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "avahi-publicservice_p.h"
 
@@ -40,7 +28,7 @@ PublicService::PublicService(const QString &name, const QString &type, unsigned
                              const QString &domain, const QStringList &subtypes)
     : QObject(), ServiceBase(new PublicServicePrivate(this, name, type, domain, port))
 {
-    K_D;
+    Q_D(PublicService);
     if (domain.isNull()) {
         d->m_domain = "local.";
     }
@@ -58,7 +46,7 @@ void PublicServicePrivate::tryApply()
         commit();
     } else {
         m_parent->stop();
-        emit m_parent->published(false);
+        Q_EMIT m_parent->published(false);
     }
 }
 
@@ -74,7 +62,7 @@ void PublicServicePrivate::gotGlobalStateChanged(int state,
 
 void PublicService::setServiceName(const QString &serviceName)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_serviceName = serviceName;
     if (d->m_running) {
         d->m_group->Reset();
@@ -84,7 +72,7 @@ void PublicService::setServiceName(const QString &serviceName)
 
 void PublicService::setDomain(const QString &domain)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_domain = domain;
     if (d->m_running) {
         d->m_group->Reset();
@@ -94,7 +82,7 @@ void PublicService::setDomain(const QString &domain)
 
 void PublicService::setType(const QString &type)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_type = type;
     if (d->m_running) {
         d->m_group->Reset();
@@ -104,7 +92,7 @@ void PublicService::setType(const QString &type)
 
 void PublicService::setSubTypes(const QStringList &subtypes)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_subtypes = subtypes;
     if (d->m_running) {
         d->m_group->Reset();
@@ -114,13 +102,13 @@ void PublicService::setSubTypes(const QStringList &subtypes)
 
 QStringList PublicService::subtypes() const
 {
-    K_D;
+    Q_D(const PublicService);
     return d->m_subtypes;
 }
 
 void PublicService::setPort(unsigned short port)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_port = port;
     if (d->m_running) {
         d->m_group->Reset();
@@ -130,7 +118,7 @@ void PublicService::setPort(unsigned short port)
 
 void PublicService::setTextData(const QMap<QString, QByteArray> &textData)
 {
-    K_D;
+    Q_D(PublicService);
     d->m_textData = textData;
     if (d->m_running) {
         d->m_group->Reset();
@@ -140,13 +128,13 @@ void PublicService::setTextData(const QMap<QString, QByteArray> &textData)
 
 bool PublicService::isPublished() const
 {
-    K_D;
+    Q_D(const PublicService);
     return d->m_published;
 }
 
 bool PublicService::publish()
 {
-    K_D;
+    Q_D(PublicService);
     publishAsync();
     while (d->m_running && !d->m_published) {
         QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
@@ -156,7 +144,7 @@ bool PublicService::publish()
 
 void PublicService::stop()
 {
-    K_D;
+    Q_D(PublicService);
     if (d->m_group) {
         d->m_group->Reset();
     }
@@ -238,7 +226,7 @@ bool PublicServicePrivate::fillEntryGroup()
         }
     }
 
-    Q_FOREACH (const QString &subtype, m_subtypes) {
+    for (const QString &subtype : qAsConst(m_subtypes)) {
         m_group->AddServiceSubtype(-1, -1, 0, m_serviceName, m_type, domainToDNS(m_domain), subtype);
     }
     return true;
@@ -252,7 +240,7 @@ void PublicServicePrivate::serverStateChanged(int s, const QString &)
     switch (s) {
     case AVAHI_SERVER_INVALID:
         m_parent->stop();
-        emit m_parent->published(false);
+        Q_EMIT m_parent->published(false);
         break;
     case AVAHI_SERVER_REGISTERING:
     case AVAHI_SERVER_COLLISION:
@@ -271,7 +259,7 @@ void PublicServicePrivate::serverStateChanged(int s, const QString &)
 
 void PublicService::publishAsync()
 {
-    K_D;
+    Q_D(PublicService);
     if (d->m_running) {
         stop();
     }
@@ -306,7 +294,7 @@ void PublicServicePrivate::groupStateChanged(int s,  const QString &reason)
     }
     case AVAHI_ENTRY_GROUP_ESTABLISHED:
         m_published = true;
-        emit m_parent->published(true);
+        Q_EMIT m_parent->published(true);
         break;
     case AVAHI_ENTRY_GROUP_FAILURE:
         serverStateChanged(AVAHI_SERVER_INVALID, reason);
